# ItalyGPT

![Logo](https://italygpt.it/static/logo.png)

ItalyGPT is an italian website, giving access to gpt for italians when ChatGPT was banned in Italy and now giving access to gpt3.5-turbo for free and gpt4 cheaper than OpenAI.

[How to Use](https://github.com/uesleibros/OpenGPT/tree/main/opengpt/italygpt/DOC.md)
